@@ -300,6 +300,35 @@ UPDATE public.test4
 -- update (name) takes precedence over select (name) due to ordering
 update public.test4 set name = 'foo' where name = 'bar';
 
+--
+-- Confirm that "long" parameter values will not be logged if pgaudit.log_parameter_max_size
+-- is set.
+\connect - :current_user
+ALTER ROLE regress_user2 SET pgaudit.log_parameter_max_size = 50;
+ALTER ROLE regress_user2 SET pgaudit.log_parameter = 'on';
+
+\connect - regress_user2
+PREPARE testinsert(int, text) AS
+    INSERT INTO test4 VALUES($1, $2);
+
+EXECUTE testinsert(1, '*******************************************************');
+
+DEALLOCATE testinsert;
+
+\connect - :current_user
+ALTER ROLE regress_user2 RESET pgaudit.log_parameter_max_size;
+
+\connect - regress_user2
+PREPARE testinsert(int, text) AS
+    INSERT INTO test4 VALUES($1, $2);
+
+EXECUTE testinsert(2, '*******************************************************');
+
+DEALLOCATE testinsert;
+
+\connect - :current_user
+ALTER ROLE regress_user2 RESET pgaudit.log_parameter;
+
 --
 -- Change permissions of user 1 so that session logging will be done
 \connect - :current_user
@@ -1591,26 +1620,16 @@ DROP EXTENSION pg_stat_statements;
 
 SET pgaudit.log_level = 'notice';
 
--- Check that partition scans are skipped for auditing and do no result in an empty stack
-SET pgaudit.log = 'all';
+-- Check that password redaction works with CREATE/ALTER USER MAPPING
+CREATE EXTENSION postgres_fdw;
+CREATE SERVER fdw_server FOREIGN DATA WRAPPER postgres_fdw OPTIONS (host 'foo', dbname 'foodb', port '5432');
 
-CREATE TABLE part_test (c1 int, c2 int) PARTITION BY RANGE (c1);
-CREATE TABLE part_test_1_to_10 PARTITION OF part_test FOR VALUES FROM (1) TO (10);
-INSERT INTO part_test VALUES (generate_series(1,9));
+CREATE USER MAPPING FOR regress_user1 SERVER fdw_server OPTIONS (user 'regress_user1', password 'secret');
+ALTER USER MAPPING FOR regress_user1 SERVER fdw_server OPTIONS (SET /* comment */ password 'secret2');
 
-CREATE OR REPLACE FUNCTION get_test_id(_ret REFCURSOR) RETURNS REFCURSOR
-LANGUAGE plpgsql IMMUTABLE AS $$
-BEGIN
-    OPEN _ret FOR SELECT * FROM part_test;
-    RETURN _ret;
-END $$;
-
-BEGIN;
-SELECT get_test_id('_ret');
-FETCH ALL FROM _ret;
-COMMIT;
-
-DROP TABLE part_test;
+DROP USER MAPPING FOR regress_user1 SERVER fdw_server;
+DROP SERVER fdw_server;
+DROP EXTENSION postgres_fdw;
 
 -- Cleanup
 -- Set client_min_messages up to warning to avoid noise
@@ -1621,6 +1640,7 @@ ALTER ROLE :current_user RESET pgaudit.log_catalog;
 ALTER ROLE :current_user RESET pgaudit.log_client;
 ALTER ROLE :current_user RESET pgaudit.log_level;
 ALTER ROLE :current_user RESET pgaudit.log_parameter;
+ALTER ROLE :current_user RESET pgaudit.log_parameter_max_size;
 ALTER ROLE :current_user RESET pgaudit.log_relation;
 ALTER ROLE :current_user RESET pgaudit.log_statement;
 ALTER ROLE :current_user RESET pgaudit.log_statement_once;
@@ -1630,6 +1650,7 @@ RESET pgaudit.log;
 RESET pgaudit.log_catalog;
 RESET pgaudit.log_level;
 RESET pgaudit.log_parameter;
+RESET pgaudit.log_parameter_max_size;
 RESET pgaudit.log_relation;
 RESET pgaudit.log_statement;
 RESET pgaudit.log_statement_once;
